Cloud Functions API

The Google Cloud client library for the Cloud Functions API.

Note

This package is currently experimental and published under the labs.dart.dev pub publisher in order to solicit feedback.

For packages in the labs.dart.dev publisher we generally plan to either graduate the package into a supported publisher (dart.dev, tools.dart.dev) after a period of feedback and iteration, or discontinue the package. These packages have a much higher expected rate of API and breaking changes.

Your feedback is valuable and will help us evolve this package. For general feedback, suggestions, and comments, please file an issue in the bug tracker.

What's this?

The Google Cloud client library for the Cloud Functions API.

Agent Skills

This package supports Agent Skills.

To add this package to your application and install the skills for use by your Agent, run:

dart pub add google_cloud_functions_v2
dart pub get
dart run skills@ get

Manages lightweight user-provided functions executed in response to events.

Libraries

cloudfunctions
The Google Cloud client for the Cloud Functions API.
testing
Testing fakes for Cloud Functions API.