cloudfunctions library
The Google Cloud client for the Cloud Functions API.
Manages lightweight user-provided functions executed in response to events.
Classes
- AutomaticUpdatePolicy
- Security patches are applied automatically to the runtime without requiring the function to be redeployed.
- BuildConfig
- Describes the Build step of the function that builds a container from the given source.
- BuildConfig_DockerRegistry
- Docker Registry to use for storing function Docker images.
- CreateFunctionRequest
-
Request for the
CreateFunctionmethod. - DeleteFunctionRequest
-
Request for the
DeleteFunctionmethod. - Environment
- The environment the function is hosted on.
- EventFilter
- Filters events based on exact matches on the CloudEvents attributes.
- EventTrigger
- Describes EventTrigger, used to request events to be sent from another service.
- EventTrigger_RetryPolicy
- Describes the retry policy in case of function's execution failure. Retried execution is charged as any other execution.
- Function$
- Describes a Cloud Function that contains user computation executed in response to an event. It encapsulates function and trigger configurations.
- Function$_State
- Describes the current state of the function.
- FunctionService
- Google Cloud Functions is used to deploy functions that are executed by Google in response to various events. Data connected with that event is passed to a function as the input data.
- GenerateDownloadUrlRequest
-
Request of
GenerateDownloadUrlmethod. - GenerateDownloadUrlResponse
-
Response of
GenerateDownloadUrlmethod. - GenerateUploadUrlRequest
-
Request of
GenerateSourceUploadUrlmethod. - GenerateUploadUrlResponse
-
Response of
GenerateSourceUploadUrlmethod. - GetFunctionRequest
-
Request for the
GetFunctionmethod. - ListFunctionsRequest
-
Request for the
ListFunctionsmethod. - ListFunctionsResponse
-
Response for the
ListFunctionsmethod. - ListRuntimesRequest
-
Request for the
ListRuntimesmethod. - ListRuntimesResponse
-
Response for the
ListRuntimesmethod. - ListRuntimesResponse_Runtime
- Describes a runtime and any special information (e.g., deprecation status) related to it.
- ListRuntimesResponse_RuntimeStage
- The various stages that a runtime can be in.
- LocationMetadata
- Extra GCF specific location information.
- OnDeployUpdatePolicy
- Security patches are only applied when a function is redeployed.
- OperationMetadata
- Represents the metadata of the long-running operation.
- OperationType
- The type of the long running operation.
- RepoSource
- Location of the source in a Google Cloud Source Repository.
- SecretEnvVar
- Configuration for a secret environment variable. It has the information necessary to fetch the secret value from secret manager and expose it as an environment variable.
- SecretVolume
- Configuration for a secret volume. It has the information necessary to fetch the secret value from secret manager and make it available as files mounted at the requested paths within the application container.
- SecretVolume_SecretVersion
- Configuration for a single version.
- ServiceConfig
- Describes the Service being deployed. Currently Supported : Cloud Run (fully managed).
- ServiceConfig_IngressSettings
- Available ingress settings.
- ServiceConfig_SecurityLevel
- Available security level settings.
- ServiceConfig_VpcConnectorEgressSettings
- Available egress settings.
- Source
- The location of the function source code.
- SourceProvenance
- Provenance of the source. Ways to find the original source, or verify that some source was used for this build.
- Stage
- Each Stage of the deployment process
- Stage_Name
- Possible names for a Stage
- Stage_State
- Possible states for a Stage
- StateMessage
- Informational messages about the state of the Cloud Function or Operation.
- StateMessage_Severity
- Severity of the state message.
- StorageSource
- Location of the source in an archive file in Google Cloud Storage.
- UpdateFunctionRequest
-
Request for the
UpdateFunctionmethod.
Exceptions / Errors
- BadGatewayException
- Exception thrown when the server returns a "502 Bad Gateway" response.
- BadRequestException
- Exception thrown when the server returns a "400 Bad Request" response.
- CancelledException
- Exception thrown when the server returns a "499 Cancelled" response.
- ConfigurationException
- Exception thrown when a method is called without correct configuration.
- ConflictException
- Exception thrown when the server returns a "409 Conflict" response.
- ForbiddenException
- Exception thrown when the server returns a "403 Forbidden" response.
- GatewayTimeoutException
- Exception thrown when the server returns a "504 Gateway Timeout" response.
- InternalServerErrorException
- Exception thrown when the server returns a "500 Internal Server Error" response.
- LengthRequiredException
- Exception thrown when the server returns a "411 Length Required" response.
- MethodNotAllowedException
- Exception thrown when the server returns a "405 Method Not Allowed" response.
- NotFoundException
- Exception thrown when the server returns a "404 Not Found" response.
- NotImplementedException
- Exception thrown when the server returns a "501 Not Implemented" response.
- NotModifiedException
- Exception thrown when the server returns a "304 Not Modified" response.
- PreconditionFailedException
- Exception thrown when the server returns a "412 Precondition Failed" response.
- RequestRangeNotSatisfiableException
- Exception thrown when the server returns a "416 Request Range Not Satisfiable" response.
- RequestTimeoutException
- Exception thrown when the server returns a "408 Request Timeout" response.
- ServiceException
- Exception thrown when an API call fails.
- Exception thrown when the server returns a "503 Service Unavailable" response.
- TooManyRequestsException
- Exception thrown when the server returns a "429 Too Many Requests" response.
- Exception thrown when the server returns a "401 Unauthorized" response.