Environment class final

The environment the function is hosted on.

Constructors

Environment(String value)
const
Environment.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const Environment
The default value for Environment.
environmentUnspecified → const Environment
Unspecified
gen1 → const Environment
Gen 1
gen2 → const Environment
Gen 2