getIamPolicy method

Future<Policy> getIamPolicy(
  1. GetIamPolicyRequest request
)

Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Policy> getIamPolicy(GetIamPolicyRequest request) async {
  final url = _endPoint.replace(
    path: '/v2/${request.resource}:getIamPolicy',
    queryParameters: {
      if (request.options?.requestedPolicyVersion case final $1?
          when $1.isNotDefault)
        'options.requestedPolicyVersion': '${$1}',
    },
  );
  final response = await _client.get(url);
  return Policy.fromJson(response);
}