listFunctions method

Returns a list of functions that belong to the requested project.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<ListFunctionsResponse> listFunctions(
  ListFunctionsRequest request,
) async {
  final url = _endPoint.replace(
    path: '/v2/${request.parent}/functions',
    queryParameters: {
      if (request.pageSize case final $1 when $1.isNotDefault)
        'pageSize': '${$1}',
      if (request.pageToken case final $1 when $1.isNotDefault)
        'pageToken': $1,
      if (request.filter case final $1 when $1.isNotDefault) 'filter': $1,
      if (request.orderBy case final $1 when $1.isNotDefault) 'orderBy': $1,
    },
  );
  final response = await _client.get(url);
  return ListFunctionsResponse.fromJson(response);
}