OperationType class final

The type of the long running operation.

Constructors

OperationType(String value)
const
OperationType.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const OperationType
The default value for OperationType.
createFunction → const OperationType
CreateFunction
deleteFunction → const OperationType
DeleteFunction
operationtypeUnspecified → const OperationType
Unspecified
updateFunction → const OperationType
UpdateFunction