createFunction method

  1. @override
Future<Operation<Function$, OperationMetadata>> createFunction(
  1. CreateFunctionRequest request
)
override

Creates a new function. If a function with the given name already exists in the specified project, the long running operation will return ALREADY_EXISTS error.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<Function$, OperationMetadata>> createFunction(
  CreateFunctionRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_createFunction case final createFunction?) {
    return createFunction(request);
  }
  throw UnsupportedError('createFunction');
}