generateDownloadUrl method

  1. @override
Future<GenerateDownloadUrlResponse> generateDownloadUrl(
  1. GenerateDownloadUrlRequest request
)
override

Returns a signed URL for downloading deployed function source code. The URL is only valid for a limited period and should be used within 30 minutes of generation. For more information about the signed URL usage see: https://cloud.google.com/storage/docs/access-control/signed-urls

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<GenerateDownloadUrlResponse> generateDownloadUrl(
  GenerateDownloadUrlRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_generateDownloadUrl case final generateDownloadUrl?) {
    return generateDownloadUrl(request);
  }
  throw UnsupportedError('generateDownloadUrl');
}