getFunction method

  1. @override
Future<Function$> getFunction(
  1. GetFunctionRequest request
)
override

Returns a function with the given name from the requested project.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Function$> getFunction(GetFunctionRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_getFunction case final getFunction?) {
    return getFunction(request);
  }
  throw UnsupportedError('getFunction');
}