listFunctions method

  1. @override
Future<ListFunctionsResponse> listFunctions(
  1. ListFunctionsRequest request
)
override

Returns a list of functions that belong to the requested project.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<ListFunctionsResponse> listFunctions(
  ListFunctionsRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_listFunctions case final listFunctions?) {
    return listFunctions(request);
  }
  throw UnsupportedError('listFunctions');
}