listRuntimes method

  1. @override
Future<ListRuntimesResponse> listRuntimes(
  1. ListRuntimesRequest request
)
override

Returns a list of runtimes that are supported for the requested project.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<ListRuntimesResponse> listRuntimes(ListRuntimesRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_listRuntimes case final listRuntimes?) {
    return listRuntimes(request);
  }
  throw UnsupportedError('listRuntimes');
}