deleteFunction method
Future<Operation<Empty, OperationMetadata> >
deleteFunction(
- DeleteFunctionRequest request
override
Deletes a function with the given name from the specified project. If the given function is used by some trigger, the trigger will be updated to remove this function.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Returns an Operation representing the status of the long-running
operation.
When complete, Operation.done will be true. If successful,
Operation.responseAsMessage will contain the operation's result.
Implementation
@override
Future<Operation<Empty, OperationMetadata>> deleteFunction(
DeleteFunctionRequest request,
) async {
if (isClosed) throw StateError('Service is closed');
if (_deleteFunction case final deleteFunction?) {
return deleteFunction(request);
}
throw UnsupportedError('deleteFunction');
}